@@ -6,7 +6,7 @@ Toadfarm - One Mojolicious app to rule them all
 
 =head1 VERSION
 
-0.60
+0.61
 
 =head1 DESCRIPTION
 
@@ -159,7 +159,7 @@ use File::Spec;
 use File::Which;
 use constant DEBUG => $ENV{TOADFARM_DEBUG} ? 1 : 0;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 BEGIN {
   $ENV{TOADFARM_ACTION} //= (@ARGV and $ARGV[0] =~ /^(reload|start|stop)$/) ? $1 : 'load';
@@ -364,7 +364,7 @@ sub _run_as {
   for my $p (File::Spec->path) {
     $sudo[0] = File::Spec->catfile($p, 'sudo');
     next unless -x $sudo[0];
-    push @sudo, qw( -H -n -u ), "#$uid";
+    push @sudo, qw( -i -n -u ), "#$uid";
     last;
   }
 
